@@ -9,6 +9,8 @@ sub upgrade
 
 	die unless $oldversion eq '1001';
 
+	print STDERR "# Schema upgrade to 1003...\n" if $OOPS::debug_upgrade;
+
 	if ($oops->{dbms} eq 'mysql') {
 		$oops->db_domany($oops->{args}, <<END);
 			
@@ -19,11 +21,12 @@ sub upgrade
 			MODIFY COLUMN pkey VARCHAR(255) BINARY;
 END
 	}
-	$oops->db_domany($oops->{args}, <<END);
-		
+	my (@r) = $oops->db_domany($oops->{args}, <<END);
+
 		UPDATE TP_object
 		SET alen = 1003
-		WHERE id = 1
+		WHERE id = 1;
+
 END
 	$oops->{arraylen}{1} = '1003';	# in case it is saved
 }
